==> phpBB-3.1.0_to_3.1.3-RC2.tar.bz2: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.1.0', 'to' => '3.1.3-RC2'),
	'files'		=> array(
		'adm/style/acp_email.html',
		'adm/style/acp_forums.html',
		'adm/style/acp_icons.html',
		'assets/javascript/core.js',
		'assets/javascript/plupload.js',
		'composer.lock',
		'config/content.yml',
		'config/db.yml',
		'config/notification.yml',
		'config/routing.yml',
		'config/services.yml',
		'includes/acp/acp_attachments.php',
		'includes/acp/acp_bbcodes.php',
		'includes/acp/acp_board.php',
		'includes/acp/acp_email.php',
		'includes/acp/acp_extensions.php',
		'includes/acp/acp_prune.php',
		'includes/acp/acp_styles.php',
		'includes/acp/acp_users.php',
		'includes/bbcode.php',
		'includes/constants.php',
		'includes/functions.php',
		'includes/functions_admin.php',
		'includes/functions_content.php',
		'includes/functions_convert.php',
		'includes/functions_display.php',
		'includes/functions_posting.php',
		'includes/mcp/mcp_forum.php',
		'includes/mcp/mcp_logs.php',
		'includes/mcp/mcp_main.php',
		'includes/message_parser.php',
		'includes/startup.php',
		'includes/ucp/ucp_auth_link.php',
		'includes/ucp/ucp_login_link.php',
		'includes/ucp/ucp_pm_viewmessage.php',
		'includes/ucp/ucp_register.php',
		'index.php',
		'language/en/acp/board.php',
		'language/en/acp/common.php',
		'language/en/acp/permissions.php',
		'language/en/acp/search.php',
		'language/en/acp/styles.php',
		'language/en/install.php',
		'language/en/mcp.php',
		'language/en/memberlist.php',
		'language/en/search.php',
		'mcp.php',
		'memberlist.php',
		'phpbb/auth/auth.php',
		'phpbb/auth/provider/apache.php',
		'phpbb/auth/provider/db.php',
		'phpbb/auth/provider_collection.php',
		'phpbb/avatar/manager.php',
		'phpbb/captcha/plugins/recaptcha.php',
		'phpbb/config/db.php',
		'phpbb/content_visibility.php',
		'phpbb/controller/helper.php',
		'phpbb/db/migration/container_aware_migration.php',
		'phpbb/db/migration/data/v30x/release_3_0_13.php',
		'phpbb/db/migration/data/v30x/release_3_0_13_pl1.php',
		'phpbb/db/migration/data/v30x/release_3_0_13_rc1.php',
		'phpbb/db/migration/data/v30x/release_3_0_5_rc1.php',
		'phpbb/db/migration/data/v310/captcha_plugins.php',
		'phpbb/db/migration/data/v310/mysql_fulltext_drop.php',
		'phpbb/db/migration/data/v310/postgres_fulltext_drop.php',
		'phpbb/db/migration/data/v310/reset_missing_captcha_plugin.php',
		'phpbb/db/migration/data/v310/soft_delete_mod_convert.php',
		'phpbb/db/migration/data/v310/style_update_p1.php',
		'phpbb/db/migration/data/v31x/m_softdelete_global.php',
		'phpbb/db/migration/data/v31x/plupload_last_gc_dynamic.php',
		'phpbb/db/migration/data/v31x/profilefield_remove_underscore_from_alpha.php',
		'phpbb/db/migration/data/v31x/profilefield_yahoo_update_url.php',
		'phpbb/db/migration/data/v31x/style_update.php',
		'phpbb/db/migration/data/v31x/update_custom_bbcodes_with_idn.php',
		'phpbb/db/migration/data/v31x/v311.php',
		'phpbb/db/migration/data/v31x/v312.php',
		'phpbb/db/migration/data/v31x/v312rc1.php',
		'phpbb/db/migration/data/v31x/v313rc1.php',
		'phpbb/db/migration/data/v31x/v313rc2.php',
		'phpbb/db/migration/profilefield_base_migration.php',
		'phpbb/db/migration/tool/module.php',
		'phpbb/db/migration/tool/permission.php',
		'phpbb/db/migrator.php',
		'phpbb/db/tools.php',
		'phpbb/di/extension/config.php',
		'phpbb/error_collector.php',
		'phpbb/event/dispatcher.php',
		'phpbb/event/dispatcher_interface.php',
		'phpbb/event/kernel_exception_subscriber.php',
		'phpbb/exception/exception_interface.php',
		'phpbb/exception/http_exception.php',
		'phpbb/exception/runtime_exception.php',
		'phpbb/extension/metadata_manager.php',
		'phpbb/file_downloader.php',
		'phpbb/log/log.php',
		'phpbb/message/admin_form.php',
		'phpbb/message/form.php',
		'phpbb/message/topic_form.php',
		'phpbb/notification/manager.php',
		'phpbb/path_helper.php',
		'phpbb/profilefields/type/type_base.php',
		'phpbb/profilefields/type/type_bool.php',
		'phpbb/profilefields/type/type_string_common.php',
		'phpbb/profilefields/type/type_url.php',
		'phpbb/request/request.php',
		'phpbb/request/request_interface.php',
		'phpbb/search/fulltext_native.php',
		'phpbb/session.php',
		'phpbb/symfony_request.php',
		'phpbb/template/twig/twig.php',
		'phpbb/version_helper.php',
		'posting.php',
		'report.php',
		'search.php',
		'styles/prosilver/style.cfg',
		'styles/prosilver/template/confirm_delete_body.html',
		'styles/prosilver/template/forumlist_body.html',
		'styles/prosilver/template/index_body.html',
		'styles/prosilver/template/mcp_front.html',
		'styles/prosilver/template/memberlist_email.html',
		'styles/prosilver/template/memberlist_search.html',
		'styles/prosilver/template/overall_footer.html',
		'styles/prosilver/template/overall_header.html',
		'styles/prosilver/template/posting_buttons.html',
		'styles/prosilver/template/simple_header.html',
		'styles/prosilver/template/ucp_pm_viewmessage.html',
		'styles/prosilver/template/ucp_pm_viewmessage_print.html',
		'styles/prosilver/template/viewtopic_body.html',
		'styles/prosilver/template/viewtopic_print.html',
		'styles/prosilver/theme/bidi.css',
		'styles/prosilver/theme/common.css',
		'styles/prosilver/theme/content.css',
		'styles/prosilver/theme/cp.css',
		'styles/subsilver2/style.cfg',
		'styles/subsilver2/template/confirm_delete_body.html',
		'styles/subsilver2/template/index.htm',
		'styles/subsilver2/template/index_body.html',
		'styles/subsilver2/template/mcp_front.html',
		'styles/subsilver2/template/memberlist_email.html',
		'styles/subsilver2/template/memberlist_search.html',
		'styles/subsilver2/template/overall_footer.html',
		'styles/subsilver2/template/overall_header.html',
		'styles/subsilver2/template/posting_buttons.html',
		'styles/subsilver2/template/posting_poll_body.html',
		'styles/subsilver2/template/simple_header.html',
		'styles/subsilver2/template/ucp_pm_viewmessage_print.html',
		'styles/subsilver2/template/viewtopic_body.html',
		'styles/subsilver2/template/viewtopic_print.html',
		'styles/subsilver2/theme/images/index.htm',
		'ucp.php',
		'viewforum.php',
		'viewtopic.php',
	),
	'binary'		=> array(),
	'deleted'		=> array(),
);

==> phpBB-3.1.1_to_3.1.4-RC2.tar.bz2: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.1.1', 'to' => '3.1.4-RC2'),
	'files'		=> array(
		'adm/style/acp_email.html',
		'adm/style/acp_forums.html',
		'adm/style/acp_icons.html',
		'adm/style/acp_users_profile.html',
		'adm/style/install_header.html',
		'adm/style/install_update_diff.html',
		'adm/style/overall_header.html',
		'adm/style/simple_header.html',
		'assets/javascript/core.js',
		'assets/javascript/plupload.js',
		'composer.lock',
		'config/content.yml',
		'config/db.yml',
		'config/notification.yml',
		'config/routing.yml',
		'config/services.yml',
		'faq.php',
		'includes/acp/acp_attachments.php',
		'includes/acp/acp_bbcodes.php',
		'includes/acp/acp_board.php',
		'includes/acp/acp_email.php',
		'includes/acp/acp_extensions.php',
		'includes/acp/acp_profile.php',
		'includes/acp/acp_prune.php',
		'includes/acp/acp_search.php',
		'includes/acp/acp_styles.php',
		'includes/acp/acp_users.php',
		'includes/bbcode.php',
		'includes/constants.php',
		'includes/functions.php',
		'includes/functions_acp.php',
		'includes/functions_admin.php',
		'includes/functions_content.php',
		'includes/functions_convert.php',
		'includes/functions_display.php',
		'includes/functions_download.php',
		'includes/functions_mcp.php',
		'includes/functions_messenger.php',
		'includes/functions_posting.php',
		'includes/functions_privmsgs.php',
		'includes/functions_user.php',
		'includes/mcp/mcp_forum.php',
		'includes/mcp/mcp_front.php',
		'includes/mcp/mcp_logs.php',
		'includes/mcp/mcp_main.php',
		'includes/mcp/mcp_queue.php',
		'includes/mcp/mcp_topic.php',
		'includes/message_parser.php',
		'includes/startup.php',
		'includes/ucp/ucp_login_link.php',
		'includes/ucp/ucp_pm_compose.php',
		'includes/ucp/ucp_pm_viewmessage.php',
		'includes/ucp/ucp_prefs.php',
		'includes/ucp/ucp_profile.php',
		'includes/ucp/ucp_register.php',
		'index.php',
		'language/en/acp/board.php',
		'language/en/acp/common.php',
		'language/en/acp/permissions.php',
		'language/en/acp/search.php',
		'language/en/acp/styles.php',
		'language/en/email/short/newtopic_notify.txt',
		'language/en/email/short/topic_notify.txt',
		'language/en/help_faq.php',
		'language/en/install.php',
		'language/en/mcp.php',
		'language/en/memberlist.php',
		'language/en/search.php',
		'mcp.php',
		'memberlist.php',
		'phpbb/auth/provider/apache.php',
		'phpbb/auth/provider/db.php',
		'phpbb/auth/provider/ldap.php',
		'phpbb/avatar/driver/local.php',
		'phpbb/avatar/driver/upload.php',
		'phpbb/avatar/manager.php',
		'phpbb/cache/driver/file.php',
		'phpbb/captcha/plugins/qa.php',
		'phpbb/captcha/plugins/recaptcha.php',
		'phpbb/config/db.php',
		'phpbb/config/db_text.php',
		'phpbb/content_visibility.php',
		'phpbb/controller/helper.php',
		'phpbb/db/driver/mysqli.php',
		'phpbb/db/migration/container_aware_migration.php',
		'phpbb/db/migration/data/v30x/release_3_0_13.php',
		'phpbb/db/migration/data/v30x/release_3_0_13_pl1.php',
		'phpbb/db/migration/data/v30x/release_3_0_13_rc1.php',
		'phpbb/db/migration/data/v30x/release_3_0_14_rc1.php',
		'phpbb/db/migration/data/v30x/release_3_0_5_rc1.php',
		'phpbb/db/migration/data/v310/avatars.php',
		'phpbb/db/migration/data/v310/captcha_plugins.php',
		'phpbb/db/migration/data/v310/mysql_fulltext_drop.php',
		'phpbb/db/migration/data/v310/postgres_fulltext_drop.php',
		'phpbb/db/migration/data/v310/reset_missing_captcha_plugin.php',
		'phpbb/db/migration/data/v310/soft_delete_mod_convert.php',
		'phpbb/db/migration/data/v310/style_update_p1.php',
		'phpbb/db/migration/data/v31x/m_softdelete_global.php',
		'phpbb/db/migration/data/v31x/plupload_last_gc_dynamic.php',
		'phpbb/db/migration/data/v31x/profilefield_remove_underscore_from_alpha.php',
		'phpbb/db/migration/data/v31x/profilefield_yahoo_update_url.php',
		'phpbb/db/migration/data/v31x/update_custom_bbcodes_with_idn.php',
		'phpbb/db/migration/data/v31x/v312.php',
		'phpbb/db/migration/data/v31x/v312rc1.php',
		'phpbb/db/migration/data/v31x/v313.php',
		'phpbb/db/migration/data/v31x/v313rc1.php',
		'phpbb/db/migration/data/v31x/v313rc2.php',
		'phpbb/db/migration/data/v31x/v314rc1.php',
		'phpbb/db/migration/data/v31x/v314rc2.php',
		'phpbb/db/migration/profilefield_base_migration.php',
		'phpbb/db/migration/tool/module.php',
		'phpbb/db/migration/tool/permission.php',
		'phpbb/db/migrator.php',
		'phpbb/db/tools.php',
		'phpbb/di/extension/config.php',
		'phpbb/error_collector.php',
		'phpbb/event/dispatcher.php',
		'phpbb/event/dispatcher_interface.php',
		'phpbb/event/kernel_exception_subscriber.php',
		'phpbb/event/kernel_terminate_subscriber.php',
		'phpbb/exception/exception_interface.php',
		'phpbb/exception/http_exception.php',
		'phpbb/exception/runtime_exception.php',
		'phpbb/extension/metadata_manager.php',
		'phpbb/feed/base.php',
		'phpbb/file_downloader.php',
		'phpbb/log/log.php',
		'phpbb/message/admin_form.php',
		'phpbb/message/topic_form.php',
		'phpbb/notification/manager.php',
		'phpbb/notification/type/post.php',
		'phpbb/notification/type/topic.php',
		'phpbb/path_helper.php',
		'phpbb/plupload/plupload.php',
		'phpbb/profilefields/type/type_base.php',
		'phpbb/profilefields/type/type_bool.php',
		'phpbb/profilefields/type/type_string_common.php',
		'phpbb/profilefields/type/type_url.php',
		'phpbb/request/request.php',
		'phpbb/request/request_interface.php',
		'phpbb/search/fulltext_native.php',
		'phpbb/session.php',
		'phpbb/symfony_request.php',
		'phpbb/template/twig/twig.php',
		'phpbb/version_helper.php',
		'posting.php',
		'report.php',
		'search.php',
		'styles/prosilver/style.cfg',
		'styles/prosilver/template/confirm_delete_body.html',
		'styles/prosilver/template/forum_fn.js',
		'styles/prosilver/template/forumlist_body.html',
		'styles/prosilver/template/index_body.html',
		'styles/prosilver/template/mcp_front.html',
		'styles/prosilver/template/mcp_logs.html',
		'styles/prosilver/template/mcp_notes_user.html',
		'styles/prosilver/template/memberlist_email.html',
		'styles/prosilver/template/memberlist_search.html',
		'styles/prosilver/template/navbar_footer.html',
		'styles/prosilver/template/overall_footer.html',
		'styles/prosilver/template/overall_header.html',
		'styles/prosilver/template/posting_buttons.html',
		'styles/prosilver/template/posting_editor.html',
		'styles/prosilver/template/posting_pm_layout.html',
		'styles/prosilver/template/posting_poll_body.html',
		'styles/prosilver/template/search_results.html',
		'styles/prosilver/template/simple_footer.html',
		'styles/prosilver/template/simple_header.html',
		'styles/prosilver/template/ucp_pm_viewmessage.html',
		'styles/prosilver/template/ucp_pm_viewmessage_print.html',
		'styles/prosilver/template/ucp_profile_autologin_keys.html',
		'styles/prosilver/template/ucp_profile_profile_info.html',
		'styles/prosilver/template/ucp_profile_reg_details.html',
		'styles/prosilver/template/viewforum_body.html',
		'styles/prosilver/template/viewtopic_body.html',
		'styles/prosilver/template/viewtopic_print.html',
		'styles/prosilver/theme/bidi.css',
		'styles/prosilver/theme/buttons.css',
		'styles/prosilver/theme/colours.css',
		'styles/prosilver/theme/common.css',
		'styles/prosilver/theme/content.css',
		'styles/prosilver/theme/cp.css',
		'styles/subsilver2/style.cfg',
		'styles/subsilver2/template/confirm_delete_body.html',
		'styles/subsilver2/template/forumlist_body.html',
		'styles/subsilver2/template/index.htm',
		'styles/subsilver2/template/index_body.html',
		'styles/subsilver2/template/mcp_front.html',
		'styles/subsilver2/template/memberlist_body.html',
		'styles/subsilver2/template/memberlist_email.html',
		'styles/subsilver2/template/memberlist_search.html',
		'styles/subsilver2/template/overall_footer.html',
		'styles/subsilver2/template/overall_header.html',
		'styles/subsilver2/template/posting_body.html',
		'styles/subsilver2/template/posting_buttons.html',
		'styles/subsilver2/template/posting_poll_body.html',
		'styles/subsilver2/template/search_results.html',
		'styles/subsilver2/template/simple_header.html',
		'styles/subsilver2/template/ucp_avatar_options_local.html',
		'styles/subsilver2/template/ucp_pm_viewmessage_print.html',
		'styles/subsilver2/template/ucp_profile_autologin_keys.html',
		'styles/subsilver2/template/ucp_profile_profile_info.html',
		'styles/subsilver2/template/ucp_profile_reg_details.html',
		'styles/subsilver2/template/viewtopic_body.html',
		'styles/subsilver2/template/viewtopic_print.html',
		'styles/subsilver2/theme/images/index.htm',
		'styles/subsilver2/theme/stylesheet.css',
		'ucp.php',
		'viewforum.php',
		'viewtopic.php',
		'web.config',
	),
	'binary'		=> array(),
	'deleted'		=> array(),
);
